==> lightbox_tobii-1.0.1.tar.gz: lightbox_tobii/modules/lightbox_media_tobii/src/Plugin/Field/FieldFormatter/LightboxTobiiMediaContainerFormatter.php <==
<?php

namespace Drupal\lightbox_media_tobii\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\Attribute\FieldFormatter;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\lightbox_media\Plugin\Field\FieldFormatter\LightboxMediaContainerFormatter;
use Drupal\lightbox_tobii\Plugin\Field\FieldFormatter\LightboxTobiiFormatterTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Plugin implementation of the 'lightbox_media_tobii' formatter.
 */
#[FieldFormatter(
  id: 'lightbox_tobii_media_container',
  label: new TranslatableMarkup('Rendered entity in Tobii container'),
  field_types: [
    'entity_reference',
  ],
)]
class LightboxTobiiMediaContainerFormatter extends LightboxMediaContainerFormatter {

  use LightboxTobiiFormatterTrait;

  /**
   * The constructor method.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    $instance = parent::create($container, $configuration, $plugin_id, $plugin_definition);
    $instance->configFactory = $container->get('config.factory');
    return $instance;
  }

  /**
   * {@inheritDoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $elements = parent::viewElements($items, $langcode);
    $this->attachLibraryAndGlobalSettings($elements);
    return $elements;
  }

}

==> lightbox_tobii-1.2.0.tar.gz: lightbox_tobii/modules/lightbox_media_tobii/src/Plugin/Field/FieldFormatter/LightboxTobiiMediaContainerFormatter.php <==
<?php

namespace Drupal\lightbox_media_tobii\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\Attribute\FieldFormatter;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\lightbox_media\Plugin\Field\FieldFormatter\LightboxMediaContainerFormatter;
use Drupal\lightbox_tobii\Plugin\Field\FieldFormatter\LightboxTobiiFormatterTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Plugin implementation of the 'lightbox_tobii_media_container' formatter.
 */
#[FieldFormatter(
  id: 'lightbox_tobii_media_container',
  label: new TranslatableMarkup('Rendered entity in Tobii container'),
  field_types: [
    'entity_reference',
  ],
)]
class LightboxTobiiMediaContainerFormatter extends LightboxMediaContainerFormatter {

  use LightboxTobiiFormatterTrait;

  /**
   * The constructor method.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    $instance = parent::create($container, $configuration, $plugin_id, $plugin_definition);
    $instance->configFactory = $container->get('config.factory');
    return $instance;
  }

  /**
   * {@inheritDoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $elements = parent::viewElements($items, $langcode);
    $this->attachLibraryAndSettings($elements);
    return $elements;
  }

}
